padding

Function padding 

pub fn padding<'b, 'a, T, U: Padded, E: ParseError<T> + 'a>() -> Parser<'a, T, (), E, impl ParseFn<T, (), E> + Captures<'b> + 'a>
where T: Borrow<U> + Clone + 'a, 'a: 'b, 'b: 'a,
A parser that accepts any number of ‘padding’ symbols. Usually, this is taken to mean whitespace.

You can implement the Padded trait for your own symbol types to use this function with them.